@@ -23,6 +23,7 @@ import json
 import os
 import shutil
 import subprocess
+import sys
 import tempfile
 
 from oslo_utils import importutils
@@ -40,12 +41,12 @@ class HelpFormatter(argparse.HelpFormatter):
 
 
 def define_command(subparsers, command, callback, cmd_mapper):
-    '''Define a command in the subparsers collection.
+    """Define a command in the subparsers collection.
 
     :param subparsers: subparsers collection where the command will go
     :param command: command name
     :param callback: function that will be used to process the command
-    '''
+    """
     desc = callback.__doc__ or ''
     help = desc.strip().split('\n')[0]
     arguments = getattr(callback, 'arguments', [])
@@ -167,16 +168,23 @@ def common_params_for_list(args, fields, field_labels):
 
     params['detail'] = args.detail
 
+    requested_fields = args.fields[0] if args.fields else None
+    if requested_fields is not None:
+        params['fields'] = requested_fields
+
     return params
 
 
-def common_filters(marker=None, limit=None, sort_key=None, sort_dir=None):
+def common_filters(marker=None, limit=None, sort_key=None, sort_dir=None,
+                   fields=None):
     """Generate common filters for any list request.
 
     :param marker: entity ID from which to start returning entities.
     :param limit: maximum number of entities to return.
     :param sort_key: field to use for sorting.
     :param sort_dir: direction of sorting: 'asc' or 'desc'.
+    :param fields: a list with a specified set of fields of the resource
+                   to be returned.
     :returns: list of string filters.
     """
     filters = []
@@ -188,6 +196,8 @@ def common_filters(marker=None, limit=None, sort_key=None, sort_dir=None):
         filters.append('sort_key=%s' % sort_key)
     if sort_dir is not None:
         filters.append('sort_dir=%s' % sort_dir)
+    if fields is not None:
+        filters.append('fields=%s' % ','.join(fields))
     return filters
 
 
@@ -277,3 +287,63 @@ def bool_argument_value(arg_name, bool_str, strict=True, default=False):
         raise exc.CommandError(_("argument %(arg)s: %(err)s.")
                                % {'arg': arg_name, 'err': e})
     return val
+
+
+def check_for_invalid_fields(fields, valid_fields):
+    """Check for invalid fields.
+
+    :param fields: A list of fields specified by the user.
+    :param valid_fields: A list of valid fields.
+    :raises CommandError: If invalid fields were specified by the user.
+    """
+    if not fields:
+        return
+
+    invalid_fields = set(fields) - set(valid_fields)
+    if invalid_fields:
+        raise exc.CommandError(
+            _('Invalid field(s) requested: %(invalid)s. Valid fields '
+              'are: %(valid)s.') % {'invalid': ', '.join(invalid_fields),
+                                    'valid': ', '.join(valid_fields)})
+
+
+def get_from_stdin(info_desc):
+    """Read information from stdin.
+
+    :param info_desc: A string description of the desired information
+    :raises: InvalidAttribute if there was a problem reading from stdin
+    :returns: the string that was read from stdin
+    """
+    try:
+        info = sys.stdin.read().strip()
+    except Exception as e:
+        err = _("Cannot get %(desc)s from standard input. Error: %(err)s")
+        raise exc.InvalidAttribute(err % {'desc': info_desc, 'err': e})
+    return info
+
+
+def handle_json_or_file_arg(json_arg):
+    """Attempts to read JSON argument from file or string.
+
+    :param json_arg: May be a file name containing the JSON, or
+        a JSON string.
+    :returns: A list or dictionary parsed from JSON.
+    :raises: InvalidAttribute if the argument cannot be parsed.
+    """
+
+    if os.path.isfile(json_arg):
+        try:
+            with open(json_arg, 'r') as f:
+                json_arg = f.read().strip()
+        except Exception as e:
+            err = _("Cannot get JSON from file '%(file)s'. "
+                    "Error: %(err)s") % {'err': e, 'file': json_arg}
+            raise exc.InvalidAttribute(err)
+    try:
+        json_arg = json.loads(json_arg)
+    except ValueError as e:
+        err = (_("For JSON: '%(string)s', error: '%(err)s'") %
+               {'err': e, 'string': json_arg})
+        raise exc.InvalidAttribute(err)
+
+    return json_arg
